@@ -35,6 +35,6 @@ from .store import *
 from .tools import *
 from .uuid_generator import *
 
-__author__ = """Daniel Bakas Amuchastegui"""
+__author__ = 'Daniel Bakas Amuchastegui'
 __email__ = 'danielbakas@gmail.com'
-__version__ = '0.0.0.42'
\ No newline at end of file
+__version__ = '0.0.0.43'
\ No newline at end of file
